Description calculate_likelihood
The functions listed below are deprecated and will be defunct in
the near future. When possible, alternative functions with similar
functionality are also mentioned. Help pages for deprecated functions are
available at help("-deprecated").
calculate_likelihoodcalculate_likelihood is deprecated. It's use turned out to not be practical during research
in this package's development.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.