A function within the explore object that is used for finding highest beta terms within each topic
Usage
top_terms_segmentr(lda, type = c("lollipops", "bars"), top_n = 15, nrow = 2)Examples
lda <- SegmentR:::test_data(explore = FALSE)$lda$lda[[1]]
#> Making DTMs
#> making tuning grid
#> setting up LDAs
lda |> top_terms_segmentr(type = "lollipops")
#> $all_terms
#>
#> $max_only
#>
lda |> top_terms_segmentr(type = "bars")
#> $all_terms
#>
#> $max_only
#>